Development
^^^^^^^^^^^

To run the full test suite, the Daemontools package should be installed.

All modules should have the ``from __future__ import unicode_literals`` statement, to ensure Unicode is used by default.
